"use strict";
/**
 * react-hours
 * Copyright 2021 Marvin Schopf
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @license Apache-2.0
 * @copyright 2021 Marvin Schopf
 *
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var react_2 = __importDefault(require("@fullcalendar/react"));
var timegrid_1 = __importDefault(require("@fullcalendar/timegrid"));
var interaction_1 = __importDefault(require("@fullcalendar/interaction"));
var moment_1 = __importDefault(require("moment"));
var opening_hours_1 = __importDefault(require("opening_hours"));
moment_1.default.locale("en");
function capitalizeFirstLetter(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}
var Hours = /** @class */ (function (_super) {
    __extends(Hours, _super);
    function Hours(props) {
        var _this = _super.call(this, props) || this;
        _this.calendarRef = react_1.default.createRef();
        return _this;
    }
    Hours.prototype.importOSM = function (oh) {
        var _this = this;
        if (oh != "24/7") {
            var ohObject = new opening_hours_1.default(oh);
            var ohIterator = ohObject.getIterator(moment_1.default()
                .day("Monday")
                .set("hours", 0)
                .set("minutes", 0)
                .toDate());
            var iteratorChanges = [];
            var latestChange = void 0;
            while (ohIterator.advance(moment_1.default()
                .day("Monday")
                .add(1, "week")
                .set("hours", 23)
                .set("minutes", 59)
                .toDate())) {
                if (latestChange) {
                    if (ohIterator.getState() === false &&
                        latestChange.state === true) {
                        latestChange.to = ohIterator.getDate();
                        iteratorChanges.push(latestChange);
                        this.calendarRef.current.getApi().addEvent({
                            start: latestChange.from,
                            end: latestChange.to,
                        });
                        latestChange = null;
                    }
                }
                else {
                    latestChange = {
                        state: ohIterator.getState(),
                        from: ohIterator.getDate(),
                    };
                }
            }
        }
        else {
            [
                "Monday",
                "Tuesday",
                "Wednesday",
                "Thursday",
                "Friday",
                "Saturday",
                "Sunday",
            ].map(function (dayOfWeek) {
                _this.calendarRef.current.getApi().addEvent({
                    start: moment_1.default()
                        .day(dayOfWeek)
                        .set("hours", 0)
                        .set("minutes", 0)
                        .toDate(),
                    end: moment_1.default()
                        .day(dayOfWeek)
                        .set("hours", 23)
                        .set("minutes", 59)
                        .toDate(),
                });
            });
        }
        this.callChangeCallback();
    };
    Hours.prototype.callChangeCallback = function () {
        if (this.props.onChange) {
            this.props.onChange(this.outputOSM());
        }
    };
    Hours.prototype.componentDidMount = function () {
        if (this.props.value) {
            this.importOSM(this.props.value);
        }
    };
    Hours.prototype.getOSMString = function () {
        return this.outputOSM();
    };
    Hours.prototype.outputOSM = function () {
        var events = this.calendarRef.current
            .getApi()
            .getEvents();
        var timeFrames = {
            monday: [],
            tuesday: [],
            wednesday: [],
            thursday: [],
            friday: [],
            saturday: [],
            sunday: [],
        };
        var stringPieces = [];
        events.forEach(function (event) {
            if (event.start.getDay() === event.end.getDay()) {
                if (!timeFrames[moment_1.default(event.start).format("dddd").toLowerCase()].includes(moment_1.default(event.start).format("hh:mm") + "-" + moment_1.default(event.end).format("hh:mm"))) {
                    timeFrames[moment_1.default(event.start).format("dddd").toLowerCase()].push(moment_1.default(event.start).format("hh:mm") + "-" + moment_1.default(event.end).format("hh:mm"));
                }
            }
            else {
                var momentBegin = moment_1.default(event.start);
                var momentEnd = moment_1.default(event.end);
                if (!timeFrames[momentBegin.format("dddd").toLowerCase()].includes(momentBegin.format("hh:mm") + "-24:00")) {
                    timeFrames[momentBegin.format("dddd").toLowerCase()].push(momentBegin.format("hh:mm") + "-24:00");
                }
                if (!timeFrames[momentEnd.format("dddd").toLowerCase()].includes("00:00-" + momentEnd.format("hh:mm"))) {
                    timeFrames[momentEnd.format("dddd").toLowerCase()].push("00:00-" + momentEnd.format("hh:mm"));
                }
                var numOfInDays = momentEnd
                    .endOf("day")
                    .diff(momentBegin.startOf("day"), "days") - 1;
                for (var i = 0; i < numOfInDays; i++) {
                    if (!timeFrames[momentBegin
                        .add(i, "days")
                        .format("dddd")
                        .toLowerCase()].includes("00:00-24:00")) {
                        timeFrames[momentBegin
                            .add(i, "days")
                            .format("dddd")
                            .toLowerCase()].push();
                    }
                }
            }
        });
        [
            "monday",
            "tuesday",
            "wednesday",
            "thursday",
            "friday",
            "saturday",
            "sunday",
        ].map(function (dayOfWeek) {
            if (timeFrames[dayOfWeek] && timeFrames[dayOfWeek].length >= 1) {
                stringPieces.push(capitalizeFirstLetter(dayOfWeek.substring(0, 2)) + " " + timeFrames[dayOfWeek].join(","));
            }
        });
        return stringPieces.join("; ");
    };
    Hours.prototype.render = function () {
        var _this = this;
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(react_2.default, { ref: this.calendarRef, plugins: [interaction_1.default, timegrid_1.default], selectable: true, selectOverlap: true, select: function (selectionInfo) {
                    var existingEvents = _this.calendarRef.current
                        .getApi()
                        .getEvents();
                    var conflict = false;
                    existingEvents.forEach(function (existingEvent) {
                        if (moment_1.default(selectionInfo.start).isBetween(existingEvent.start, existingEvent.end) ||
                            moment_1.default(selectionInfo.end).isBetween(existingEvent.start, existingEvent.end) ||
                            moment_1.default(existingEvent.start).isBetween(selectionInfo.start, selectionInfo.end) ||
                            moment_1.default(existingEvent.end).isBetween(selectionInfo.start, selectionInfo.end)) {
                            conflict = true;
                        }
                    });
                    if (!conflict) {
                        _this.calendarRef.current.getApi().addEvent({
                            start: selectionInfo.start,
                            end: selectionInfo.end,
                        });
                        _this.callChangeCallback();
                    }
                }, locale: this.props.locale ? this.props.locale : "en", headerToolbar: false, dayHeaderFormat: {
                    weekday: "long",
                }, themeSystem: this.props.theme ? this.props.theme : "standard", eventClick: function (eventInfo) {
                    eventInfo.event.remove();
                    _this.callChangeCallback();
                }, eventOverlap: false, editable: true, droppable: false })));
    };
    return Hours;
}(react_1.default.Component));
exports.default = Hours;
//# sourceMappingURL=index.js.map